pub trait Endian: Copy + Default + Debug + PartialEq + PartialOrd {
    unsafe fn write_at_le(self, dst: *mut u8);
unsafe fn write_at_be(self, dst: *mut u8);
unsafe fn write_at_ne(self, dst: *mut u8);
unsafe fn from_bytes_le(src: *const u8) -> Self;
unsafe fn from_bytes_be(src: *const u8) -> Self;
unsafe fn from_bytes_ne(src: *const u8) -> Self; }
This trait contains many unsafe methods for efficiently reading and writing data.

Those Methods are unsafe because they do not check the index bounds.

Those methods are safely used by internal. And shouldn’t expect to be used by user. You almost never have to implement this trait for your own types.

Required methods

Implementations on Foreign Types

Implementors